@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module Bundler
   class Fetcher
     class Base
@@ -20,7 +21,7 @@ module Bundler
         @fetch_uri ||= begin
           if remote_uri.host == "rubygems.org"
             uri = remote_uri.dup
-            uri.host = "bundler.rubygems.org"
+            uri.host = "index.rubygems.org"
             uri
           else
             remote_uri
@@ -28,8 +29,8 @@ module Bundler
         end
       end
 
-      def api_available?
-        api_fetcher?
+      def available?
+        true
       end
 
       def api_fetcher?
