@@ -1,7 +1,8 @@
+# frozen_string_literal: true
 module Bundler
   class SourceList
     attr_reader :path_sources,
-                :git_sources
+      :git_sources
 
     def initialize
       @path_sources       = []
@@ -40,7 +41,7 @@ module Bundler
     end
 
     def get(source)
-      source_list_for(source).find { |s| source == s }
+      source_list_for(source).find {|s| source == s }
     end
 
     def lock_sources
@@ -53,12 +54,12 @@ module Bundler
 
       [path_sources, git_sources].each do |source_list|
         source_list.map! do |source|
-          replacement_sources.find { |s| s == source } || source
+          replacement_sources.find {|s| s == source } || source
         end
       end
 
       replacement_rubygems =
-        replacement_sources.detect { |s| s.is_a?(Source::Rubygems) }
+        replacement_sources.detect {|s| s.is_a?(Source::Rubygems) }
       @rubygems_aggregate = replacement_rubygems if replacement_rubygems
 
       # Return true if there were changes
@@ -74,6 +75,10 @@ module Bundler
       all_sources.each(&:remote!)
     end
 
+    def rubygems_primary_remotes
+      @rubygems_aggregate.remotes
+    end
+
   private
 
     def add_source_to_list(source, list)
